==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/EventMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessage;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventMessageSetImpl extends InstanceSet<EventMessageSet,EventMessage> implements EventMessageSet {

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( EventMessage eventmessage : this ) eventmessage.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( EventMessage eventmessage : this ) eventmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public StateMachineEventSet R1009_generates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( EventMessage eventmessage : this ) statemachineeventset.add( eventmessage.R1009_generates_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( EventMessage eventmessage : this ) asynchronousmessageset.add( eventmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }


    @Override
    public EventMessage nullElement() {
        return EventMessageImpl.EMPTY_EVENTMESSAGE;
    }

    @Override
    public EventMessageSet emptySet() {
      return new EventMessageSetImpl();
    }

    @Override
    public EventMessageSet value() {
        return this;
    }

    @Override
    public List<EventMessage> elements() {
        return Arrays.asList(toArray(new EventMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/EventMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.AsynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessage;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.AsynchronousMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventMessageSetImpl extends InstanceSet<EventMessageSet,EventMessage> implements EventMessageSet {

    public EventMessageSetImpl() {
    }

    public EventMessageSetImpl(Comparator<? super EventMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( EventMessage eventmessage : this ) eventmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( EventMessage eventmessage : this ) eventmessage.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public StateMachineEventSet R1009_generates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( EventMessage eventmessage : this ) statemachineeventset.add( eventmessage.R1009_generates_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public AsynchronousMessageSet R1019_is_a_AsynchronousMessage() throws XtumlException {
        AsynchronousMessageSet asynchronousmessageset = new AsynchronousMessageSetImpl();
        for ( EventMessage eventmessage : this ) asynchronousmessageset.add( eventmessage.R1019_is_a_AsynchronousMessage() );
        return asynchronousmessageset;
    }


    @Override
    public EventMessage nullElement() {
        return EventMessageImpl.EMPTY_EVENTMESSAGE;
    }

    @Override
    public EventMessageSet emptySet() {
      return new EventMessageSetImpl();
    }

    @Override
    public EventMessageSet emptySet(Comparator<? super EventMessage> comp) {
      return new EventMessageSetImpl(comp);
    }

    @Override
    public EventMessageSet value() {
        return this;
    }

    @Override
    public List<EventMessage> elements() {
        return Arrays.asList(toArray(new EventMessage[0]));
    }

}
